@@ -42,7 +42,8 @@ class MovieMarkdownGenerator:
         self,
         movielens,
         tmdb_api_token,
-        placeholder_image_url="https://upload.wikimedia.org/wikipedia/commons/thumb/3/3f/Placeholder_view_vector.svg/681px-Placeholder_view_vector.svg.png",
+        placeholder_image_url="https://upload.wikimedia.org/"
+        "wikipedia/commons/thumb/3/3f/Placeholder_view_vector.svg/681px-Placeholder_view_vector.svg.png",
     ):
         self.movielens = movielens
         self.tmdb_api_token = tmdb_api_token
@@ -121,7 +122,7 @@ class Session:
         self.movie_id, self.initial_markdown, self.initial_poster_url = self.content()
         self.content_task = self.content()
 
-    @profile()
+    @Timer()
     def content(self):
         explicit = self.recommender.to_torch_coo(
             scipy.sparse.coo_matrix(np.nan_to_num(self.explicit).reshape(1, -1))
@@ -144,6 +145,7 @@ class Session:
     async def async_content(self):
         return self.content()
 
+    @Timer()
     def save_rating(self, rating, movie_id):
         if self.explicit[movie_id] != 0:
             raise ValueError(
@@ -191,10 +193,9 @@ class Session:
             wandb.log(dict(upload_error=str(e)))
             return f"Couldn't read imdb ratings file: \n{str(e)}"
 
-        with torch.no_grad():
-            recommendations = self.recommender.online_recommend(
-                explicit, n_recommendations=self.n_recommendations
-            )
+        recommendations = self.recommender.online_recommend(
+            explicit, n_recommendations=self.n_recommendations
+        )
 
         markdown = ""
         for i, item_id in enumerate(recommendations[0].numpy(), start=1):
@@ -215,6 +216,7 @@ def gradio_relative_html_path(relative_path):
     return os.path.join("file", relative_path)
 
 
+@profile()
 def build_app_blocks(
     recommender: "RecommenderModuleBase",
     movie_markdown_generator: MovieMarkdownGenerator,
