@@ -223,34 +223,34 @@ class CatBoostMetrics(pl.callbacks.Callback):
 
     @staticmethod
     def log_feature_names(model: "CatboostInterface"):
-        ...
-        # model.cached_indexed_features_dataframe doesn't have all the features -> wrong description
-        # cat_features = {k.value: list(v) for k, v in model.cat_features.items()}
-        # text_features = {k.value: list(v) for k, v in model.text_features.items()}
-        # non_numeric_features = sum(cat_features.values(), start=[]) + sum(
-        #     text_features.values(), start=[]
-        # )
-        # numeric_features = {}
-        # for kind in model.FeatureKind:
-        #     if (features := model.cached_indexed_features_dataframe(kind)) is not None:
-        #         numeric_features[kind.value] = list(
-        #             features.columns.difference(non_numeric_features)
-        #         )
-        # features_description = pd.DataFrame(
-        #     dict(
-        #         cat_features=cat_features,
-        #         text_features=text_features,
-        #         numeric_features=numeric_features,
-        #     )
-        # ).reset_index()
-        # wandb.log(dict(features=wandb.Table(dataframe=features_description)))
+        dataframe = model.train_user_item_dataframe
+        dataframe = model.merge_features(dataframe)
+        pool_kwargs = model.extract_pool_kwargs(dataframe=dataframe)
+        cat_features = pool_kwargs["cat_features"]
+        text_features = pool_kwargs["text_features"]
+        numeric_features = (
+            pool_kwargs["dataframe"]
+            .columns.difference(cat_features)
+            .difference(text_features)
+        ).tolist()
+        features_description = pd.Series(
+            dict(
+                cat_features=cat_features,
+                text_features=text_features,
+                numeric_features=numeric_features,
+            )
+        )
+        features_description = features_description.to_frame().T
+        wandb.log(dict(features=wandb.Table(dataframe=features_description)))
 
     @staticmethod
     def log_single_user_features_dataframe_with_ratings_and_explicit(
         model: "CatboostInterface", dataframe: pd.DataFrame, stage: str
     ):
         user_id = dataframe.reset_index()["user_id"].sample(1).values[0]
-        offline_dataframe = dataframe.query(f"user_id == @user_id")
+        offline_dataframe = dataframe.query(
+            f"user_id == @user_id", local_dict=dict(user_id=user_id)
+        )
         user_explicit = coo_array(
             (
                 offline_dataframe["rating"].values,
@@ -269,15 +269,18 @@ class CatBoostMetrics(pl.callbacks.Callback):
         for kind, dataframe in zip(
             ["offline", "online"], [offline_dataframe, online_dataframe]
         ):
-            pool = model.pool(user_item_dataframe=dataframe)
-            features_dataframe = model.merge_features(dataframe)
+            dataframe = model.merge_features(dataframe)
+            pool_kwargs = model.extract_pool_kwargs(dataframe=dataframe)
+            postprocessed_pool_kwargs = model.postprocess_pool_kwargs(**pool_kwargs)
+            pool = catboost.Pool(**postprocessed_pool_kwargs)
+            features_dataframe = pool_kwargs["dataframe"]
             with filter_warnings(
                 action="ignore", category=pd.errors.SettingWithCopyWarning
             ):
                 features_dataframe["ratings"] = model.model.predict(pool)
             features_dataframe = features_dataframe.sort_values(
                 "ratings", ascending=False
-            ).reset_index()
+            )
             wandb.log(
                 {
                     f"{stage} {kind} user dataframe": wandb.Table(
