@@ -247,6 +247,7 @@ class CatboostInterface(
         self.model.load_model("tmp")
         self._shap_explainer = pickle.loads(bytes_dict["shap_explainer_bytes"])
 
+    @Timer()
     def setup_cache(self):
         for kind in self.FeatureKind:
             self.cached_indexed_features_dataframe(kind=kind)
@@ -735,9 +736,6 @@ class CatboostAggregatorRecommender(CatboostInterface):
             counter.update([name])
         return names
 
-    # def user_item_features(self):
-    #     return self.FeatureReturnValue(cat_features=set(self.recommender_names))
-
     def ranks_dataframe(self, user_ids, item_ids, ranks):
         """
         :param user_ids: tensor of shape [n_rows]
